@@ -152,9 +152,8 @@ meta.lm.stdmean2 <- function(alpha, m1, m2, sd1, sd2, n1, n2, X, stdzr) {
   df1 <- n1 - 1
   df2 <- n2 - 1
   m <- length(m1)
-  nt <- sum(n1 + n2)
+  n <- sum(n1 + n2)
   z <- qnorm(1 - alpha/2)
-  n <- n1 + n2
   v1 <- sd1^2
   v2 <- sd2^2
   if (stdzr == 0) {
@@ -307,7 +306,7 @@ meta.lm.mean.ps <- function(alpha, m1, m2, sd1, sd2, cor, n, X) {
 #' row per predictor.  The matrix has the following columns:
 #' * Estimate - OLS estimate
 #' * SE - standard error
-#' * t - t-value
+#' * z - z-value
 #' * p - p-value
 #' * LL - lower limit of the confidence interval
 #' * UL - upper limit of the confidence interval
@@ -340,7 +339,6 @@ meta.lm.mean.ps <- function(alpha, m1, m2, sd1, sd2, cor, n, X) {
 #' @export
 meta.lm.stdmean.ps <- function(alpha, m1, m2, sd1, sd2, cor, n, X, stdzr) {
   m <- length(m1)
-  nt <- sum(n)
   df <- n - 1
   z <- qnorm(1 - alpha/2)
   v1 <- sd1^2
@@ -418,6 +416,10 @@ meta.lm.stdmean.ps <- function(alpha, m1, m2, sd1, sd2, cor, n, X, stdzr) {
 #' * exp(UL) - upper limit of the exponentiated confidence interval
 #' 
 #' 
+#' @references
+#' \insertRef{Bonett2020}{vcmeta}
+#'
+#'
 #' @examples
 #' n1 <- c(65, 30, 29, 45, 50)
 #' n2 <- c(67, 32, 31, 20, 52)
@@ -443,7 +445,6 @@ meta.lm.stdmean.ps <- function(alpha, m1, m2, sd1, sd2, cor, n, X, stdzr) {
 #' @export
 meta.lm.meanratio2 <- function(alpha, m1, m2, sd1, sd2, n1, n2, X) {
   m <- length(m1)
-  nt <- sum(n1 + n2)
   var1 <- sd1^2/(n1*m1^2) 
   var2 <- sd2^2/(n2*m2^2)
   var <- var1 + var2
@@ -508,6 +509,10 @@ meta.lm.meanratio2 <- function(alpha, m1, m2, sd1, sd2, n1, n2, X) {
 #'  * exp(UL) - upper limit of the exponentiated confidence interval
 #' 
 #' 
+#' @references
+#' \insertRef{Bonett2020}{vcmeta}
+#' 
+#' 
 #' @examples
 #' n <- c(65, 30, 29, 45, 50)
 #' cor <- c(.87, .92, .85, .90, .88)
@@ -533,7 +538,6 @@ meta.lm.meanratio2 <- function(alpha, m1, m2, sd1, sd2, n1, n2, X) {
 #' @export
 meta.lm.meanratio.ps <- function(alpha, m1, m2, sd1, sd2, cor, n, X) {
   m <- length(m1)
-  nt <- sum(n)
   var <- (sd1^2/m1^2 + sd2^2/m2^2 - 2*cor*sd1*sd2/(m1*m2))/n
   y <- log(m1/m2)
   x0 <- matrix(c(1), m, 1)
@@ -543,7 +547,6 @@ meta.lm.meanratio.ps <- function(alpha, m1, m2, sd1, sd2, cor, n, X) {
   b <- M%*%t(X)%*%y
   V <- diag(var)
   se <- sqrt(diag(M%*%t(X)%*%V%*%X%*%M))
-  df <- nt - q
   crit <- qnorm(1 - alpha/2)
   ll <- b - crit*se
   ul <- b + crit*se
@@ -681,7 +684,6 @@ meta.lm.cor.gen <- function(alpha, cor, se, X) {
 #' @export
 meta.lm.cor <- function(alpha, n, cor, s, X) {
   m <- length(n)
-  nt <- sum(n)
   z <- qnorm(1 - alpha/2)
   zcor <- log((1 + cor)/(1 - cor))/2
   zvar <- 1/(n - 3 - s)
@@ -755,7 +757,6 @@ meta.lm.cor <- function(alpha, n, cor, s, X) {
 #' @export
 meta.lm.spear <- function(alpha, n, cor, X) {
   m <- length(n)
-  nt <- sum(n)
   z <- qnorm(1 - alpha/2)
   zcor <- log((1 + cor)/(1 - cor))/2
   zvar <- (1 + cor^2/2)/(n - 3)
@@ -830,7 +831,6 @@ meta.lm.spear <- function(alpha, n, cor, X) {
 #' @export
 meta.lm.semipart <- function(alpha, n, cor, r2, X) {
   m <- length(n)
-  nt <- sum(n)
   z <- qnorm(1 - alpha/2)
   r0 <- r2 - cor^2
   zcor <- log((1 + cor)/(1 - cor))/2
@@ -899,7 +899,8 @@ meta.lm.semipart <- function(alpha, n, cor, r2, X) {
 #' 
 #' 
 #' @references
-#' \insertRef{Bonett2010}{vcmeta}
+#' * \insertRef{Bonett2010}{vcmeta}
+#' * \insertRef{Bonett2015b}{vcmeta}
 #' 
 #' 
 #' @importFrom stats pnorm
@@ -907,7 +908,6 @@ meta.lm.semipart <- function(alpha, n, cor, r2, X) {
 #' @export
 meta.lm.cronbach <- function(alpha, n, rel, r, X) {
   m <- length(n)
-  nt <- sum(n)
   z <- qnorm(1 - alpha/2)
   hn <- m/sum(1/n)
   a <- ((r - 2)*(m - 1))^.25
@@ -933,7 +933,7 @@ meta.lm.cronbach <- function(alpha, n, rel, r, X) {
 }
 
 
-#  meta.lm.odds =============================================================
+#  meta.lm.oddsratio ========================================================
 #' Meta-regression analysis for odds ratios 
 #' 
 #' 
@@ -978,7 +978,7 @@ meta.lm.cronbach <- function(alpha, n, rel, r, X) {
 #' x1 <- c(4, 4, 5, 3, 26)
 #' x2 <- c(1, 1, 1, 0, 0)
 #' X <- matrix(cbind(x1, x2), 5, 2)
-#' meta.lm.odds(.05, f1, f2, n1, n2, X)
+#' meta.lm.oddsratio(.05, f1, f2, n1, n2, X)
 #' 
 #' # Should return:
 #' #        Estimate         SE           z     p         LL         UL
@@ -998,9 +998,8 @@ meta.lm.cronbach <- function(alpha, n, rel, r, X) {
 #' @importFrom stats pnorm
 #' @importFrom stats qnorm
 #' @export
-meta.lm.odds <- function(alpha, f1, f2, n1, n2, X) {
+meta.lm.oddsratio <- function(alpha, f1, f2, n1, n2, X) {
   m <- length(n1)
-  nt <- sum(n1 + n2)
   z <- qnorm(1 - alpha/2)
   lor <- log((f1 + .5)*(n2 - f2 + .5)/((f2 + .5)*(n1 - f1 + .5)))
   var <- 1/(f1 + .5) + 1/(f2 + .5) + 1/(n1 - f1 + .5) + 1/(n2 - f2 + .5)
@@ -1028,12 +1027,12 @@ meta.lm.odds <- function(alpha, f1, f2, n1, n2, X) {
 
 
 #  meta.lm.propratio2 =======================================================
-#' Meta-regression analysis for proportion ratios 
+#' Meta-regression analysis for 2-group proportion ratios 
 #' 
 #'
 #' @description
 #' This function estimates the intercept and slope coefficients in a
-#' meta-regression model where the dependent variable is a log
+#' meta-regression model where the dependent variable is a 2-group log
 #' proportion ratio. The estimates are OLS estimates with robust standard 
 #' errors that accommodate residual heteroscedasticity. The exponentiated 
 #' slope estimate for a predictor variable describes a multiplicative 
@@ -1094,7 +1093,6 @@ meta.lm.odds <- function(alpha, f1, f2, n1, n2, X) {
 #' @export
 meta.lm.propratio2 <- function(alpha, f1, f2, n1, n2, X) {
   m <- length(n1)
-  nt <- sum(n1 + n2)
   z <- qnorm(1 - alpha/2)
   p1 <- (f1 + 1/4)/(n1 + 7/4) 
   p2 <- (f2 + 1/4)/(n2 + 7/4)
@@ -1179,7 +1177,6 @@ meta.lm.propratio2 <- function(alpha, f1, f2, n1, n2, X) {
 #' @export
 meta.lm.prop2 <- function(alpha, f1, f2, n1, n2, X) {
   m <- length(n1)
-  nt <- sum(n1 + n2)
   z <- qnorm(1 - alpha/2)
   p1 <- (f1 + 1/m)/(n1 + 2/m) 
   p2 <- (f2 + 1/m)/(n2 + 2/m)
@@ -1254,7 +1251,7 @@ meta.lm.prop2 <- function(alpha, f1, f2, n1, n2, X) {
 #' 
 #' 
 #' @references
-#' \insertRef{Bonett2014}{vcmeta}
+#' \insertRef{Bonett2012}{vcmeta}
 #' 
 #' 
 #' @importFrom stats pnorm
@@ -1264,7 +1261,6 @@ meta.lm.prop.ps <- function(alpha, f11, f12, f21, f22, X) {
   m <- length(f11)
   z <- qnorm(1 - alpha/2)
   n <- f11 + f12 + f21 + f22
-  nt <- sum(n)
   p12 <- (f12 + 1/m)/(n + 2/m) 
   p21 <- (f21 + 1/m)/(n + 2/m)
   rd <- p12 - p21
@@ -1334,6 +1330,10 @@ meta.lm.prop.ps <- function(alpha, f11, f12, f21, f22, X) {
 #' # b2 0.4205147 0.32383556 1.2985438 0.194 -0.21419136 1.0552207
 #' 
 #' 
+#' @references 
+#' \insertRef{Bonett2022}{vcmeta}
+#' 
+#' 
 #' @importFrom stats pnorm
 #' @importFrom stats qnorm
 #' @export
@@ -1341,7 +1341,6 @@ meta.lm.agree <- function(alpha, f11, f12, f21, f22, X) {
   m <- length(f11)
   z <- qnorm(1 - alpha/2)
   n <- f11 + f12 + f21 + f22
-  nt <- sum(n)
   p0 <- (f11 + f22 + 2/m)/(n + 4/m)
   g <- 2*p0 - 1 
   var <- 4*p0*(1 - p0)/(n + 4/m)
@@ -1363,6 +1362,7 @@ meta.lm.agree <- function(alpha, f11, f12, f21, f22, X) {
   return (out)
 }
 
+
 #  meta.lm.mean1 ============================================================
 #' Meta-regression analysis for 1-group means
 #' 
@@ -1414,7 +1414,6 @@ meta.lm.agree <- function(alpha, f11, f12, f21, f22, X) {
 #' @export
 meta.lm.mean1 <- function(alpha, m, sd, n, X) {
   k <- length(m)
-  nt <- sum(n)
   var <- sd^2/n
   x0 <- matrix(c(1), k, 1)
   X <- cbind(x0, X)
@@ -1483,7 +1482,6 @@ meta.lm.mean1 <- function(alpha, m, sd, n, X) {
 meta.lm.prop1 <- function(alpha, f, n, X) {
   z <- qnorm(1 - alpha/2)
   k <- length(f)
-  nt <- sum(n)
   p <- (f + 2/k)/(n + 4/k)
   var <- p*(1 - p)/(n + 4/k)
   x0 <- matrix(c(1), k, 1)
