@@ -9,10 +9,8 @@
 #' intervals for the difference and average effect size are also computed. 
 #' Equality of variances within or across studies is not assumed. A
 #' Satterthwaite adjustment to the degrees of freedom is used to improve the 
-#' accuracy of the confidence intervals. The same results can be obtained using
-#' the \link[vcmeta]{meta.lc.mean2} function with appropriate contrast coefficients. 
-#' The confidence level for the difference is 1 – 2*alpha, which is recommended for 
-#' equivalence testing.
+#' accuracy of the confidence intervals. The confidence level for the difference
+#' is 1 – 2*alpha, which is recommended for equivalence testing.
 #' 
 #' 
 #' @param    alpha		 alpha level for 1-alpha confidence
@@ -815,7 +813,9 @@ replicate.oddsratio <- function(alpha, est1, se1, est2, se2){
 #' interval for the difference uses a 1 - 2*alpha confidence level, which is 
 #' recommended for equivalence testing. Use the \link[vcmeta]{replicate.gen} 
 #' function for slopes in other types of models (e.g., binary logistic, ordinal 
-#' logistic, SEM). 
+#' logistic, SEM). A Satterthwaite adjustment to the degrees of freedom is used
+#' to improve the accuracy of the confidence intervals for the average and the
+#' difference.
 #'
 #'
 #' @param    alpha	alpha level for 1-alpha or 1 - 2alpha confidence
@@ -1093,7 +1093,7 @@ replicate.spear <- function(alpha, cor1, n1, cor2, n2) {
 
 
 #  replicate.prop1 ============================================================
-#' Compares and combines single proportion in original and follow-up studies
+#' Compares and combines single proportions in original and follow-up studies
 #' 
 #'
 #' @description 
@@ -1104,11 +1104,11 @@ replicate.spear <- function(alpha, cor1, n1, cor2, n2) {
 #' which is recommended for equivalence testing.
 #' 
 #' 
-#' @param    alpha		 alpha level for 1-alpha confidence
-#' @param    f1	  	   frequency count in original study 
+#' @param    alpha	 alpha level for 1-alpha confidence
+#' @param    f1	  	 frequency count in original study 
 #' @param    n1     	 sample size in original study
-#' @param    f2 	   	 frequency count in follow-up study 
-#' @param    n2    	 	 sample size for in follow-up study
+#' @param    f2 	 frequency count in follow-up study 
+#' @param    n2    	 sample size for in follow-up study
 #' 
 #' 
 #' @return A 4-row matrix. The rows are:
@@ -1261,7 +1261,7 @@ replicate.mean1 <- function(alpha, m1, sd1, n1, m2, sd2, n2){
 }
 
 
-# replicate.ratio.prop2 =======================================================
+# replicate.propratio2 =======================================================
 #' Compares and combines 2-group proportion ratios in original and follow-up 
 #' studies
 #' 
@@ -1293,13 +1293,13 @@ replicate.mean1 <- function(alpha, m1, sd1, n1, m2, sd2, n2){
 #'
 #'
 #' The columns are:
-#' * Estimate - proportion difference estimate (single study, ratio, average)
+#' * Estimate - proportion ratio estimate (single study, ratio, average)
 #' * LL - lower limit of the confidence interval
 #' * UL - upper limit of the confidence interval
 #'    
 #' 
 #' @examples
-#' replicate.ratio.prop2(.05, 21, 16, 40, 40, 19, 13, 60, 60)
+#' replicate.propratio2(.05, 21, 16, 40, 40, 19, 13, 60, 60)
 #'
 #' # Should return:
 #' #                      Estimate        LL       UL
@@ -1316,7 +1316,7 @@ replicate.mean1 <- function(alpha, m1, sd1, n1, m2, sd2, n2){
 #' @importFrom stats qnorm
 #' @importFrom stats pnorm
 #' @export
-replicate.ratio.prop2 <- function(alpha, f11, f12, n11, n12, f21, f22, n21, n22){
+replicate.propratio2 <- function(alpha, f11, f12, n11, n12, f21, f22, n21, n22){
   zcrit1 <- qnorm(1 - alpha/2)
   zcrit2 <- qnorm(1 - alpha)
   p11 <- (f11 + 1/4)/(n11 + 7/4)
@@ -1403,7 +1403,8 @@ replicate.ratio.prop2 <- function(alpha, f11, f12, n11, n12, f21, f22, n21, n22)
 #' 
 #' 
 #' @references
-#' \insertRef{Bonett2021}{vcmeta}
+#' * \insertRef{Bonett2021}{vcmeta}
+#' * \insertRef{Bonett2012}{vcmeta}
 #' 
 #' 
 #' @importFrom stats qnorm
@@ -1561,3 +1562,191 @@ replicate.cor.gen <- function(alpha, cor1, se1, cor2, se2) {
   return(out)
 }
 
+
+# replicate.agree =============================================================
+#' Compares and combines G-index of agreement in original and follow-up studies
+#' 
+#'
+#' @description 
+#' This function computes adjusted Wald confidence intervals from an original 
+#' study and a follow-up study where the effect size is a G-index of agreement. 
+#' Adjusted Wald confidence intervals for the difference and average effect 
+#' size are also computed. The confidence level for the difference is 
+#' 1 – 2*alpha, which is recommended for equivalence testing. As a measurement
+#' of agreement, the G-index is usually preferred to Cohen's kappa.
+#' 
+#' 
+#' @param    alpha	     alpha level for 1-alpha confidence
+#' @param    f1		     number of objects rated in agreement in original study 
+#' @param    n1		     sample size (number of objects) in original study
+#' @param    f2		     number of objects rated in agreement in follow-up study 
+#' @param    n2		     sample size (number of objects) in follow-up study
+#' @param    k		     number of rating categories
+
+#' 
+#' 
+#' @return A 4-row matrix. The rows are:
+#' * Row 1 summarizes the original study
+#' * Row 2 summarizes the follow-up study
+#' * Row 3 estimates the difference in G-indicies
+#' * Row 4 estimates the average G-index
+#'
+#'
+#' The columns are:
+#' * Estimate - MLE of G-index (single study, difference, average)
+#' * SE - standard error of adjusted estimate
+#' * LL - lower limit of the adjusted confidence interval
+#' * UL - upper limit of the adjusted confidence interval
+#'    
+#' 
+#' @examples
+#' replicate.agree(.05, 85, 100, 160, 200, 2)
+#'
+#' # Should return:
+#' #                       Estimate         SE         LL        UL
+#' # Original:                 0.70 0.07252105  0.53093828 0.8152156
+#' # Follow-up:                0.60 0.05661961  0.47726289 0.6992077
+#' # Original - Follow-up:     0.10 0.09159681 -0.05844824 0.2428784
+#' # Average:                  0.65 0.04579840  0.55040374 0.7299302
+#' 
+#' 
+#' @references
+#' \insertRef{Bonett2022}{vcmeta}
+#' 
+#' 
+#' @importFrom stats qnorm
+#' @importFrom stats pnorm
+#' @export
+replicate.agree <- function(alpha, f1, n1, f2, n2, k){
+  zcrit1 <- qnorm(1 - alpha/2)
+  zcrit2 <- qnorm(1 - alpha)
+  a <- k/(k - 1)
+  p1 <- f1/n1
+  p2 <- f2/n2
+  p1.adj1 <- (f1 + 2)/(n1 + 4)
+  p2.adj1 <- (f2 + 2)/(n2 + 4)
+  p1.adj2 <- (f1 + 1)/(n1 + 2)
+  p2.adj2 <- (f2 + 1)/(n2 + 2)
+  est1 <- a*p1 - 1/(k - 1)
+  est2 <- a*p2 - 1/(k - 1)
+  est3 <- est1 - est2
+  est4 <- (est1 + est2)/2
+  est1.adj <- a*p1.adj1 - 1/(k - 1)
+  est2.adj <- a*p2.adj1 - 1/(k - 1)
+  est3.adj <- a*p1.adj2 - a*p2.adj2
+  est4.adj <- (a*p1.adj2 + a*p2.adj2 - 2/(k - 1))/2
+  se1 <- a*sqrt(p1.adj1*(1 - p1.adj1)/(n1 + 4))
+  se2 <- a*sqrt(p2.adj1*(1 - p2.adj1)/(n2 + 4))
+  se3 <- a*sqrt(p1.adj2*(1 - p1.adj2)/(n1 + 2) + p2.adj2*(1 - p2.adj2)/(n2 + 2))
+  se4 <- se3/2
+  ll1 <- est1.adj - zcrit1*se1;  ul1 <- est1.adj + zcrit1*se1
+  ll2 <- est2.adj - zcrit1*se2;  ul2 <- est2.adj + zcrit1*se2
+  ll3 <- est3.adj - zcrit2*se3;  ul3 <- est3.adj + zcrit2*se3
+  ll4 <- est4.adj - zcrit1*se4;  ul4 <- est4.adj + zcrit1*se4
+  out1 <- t(c(est1, se1, ll1, ul1))
+  out2 <- t(c(est2, se2, ll2, ul2))
+  out3 <- t(c(est3, se3, ll3, ul3))
+  out4 <- t(c(est4, se4, ll4, ul4))
+  out <- rbind(out1, out2, out3, out4)
+  colnames(out) <- c("Estimate", "SE", "LL", "UL")
+  rownames(out) <- c("Original:", "Follow-up:", "Original - Follow-up:", "Average:")
+  return(out)
+}
+
+
+#  replicate.cronbach =========================================================
+#' Compares and combines Cronbach reliablity in original and follow-up studies
+#' 
+#'
+#' @description 
+#' This function can be used to compare and combine a Cronbach reliablity 
+#' coefficient from an original study and a follow-up study. The confidence 
+#' level for the difference is 1 – 2*alpha, which is recommended for 
+#' equivalence testing.
+#' 
+#' 
+#' @param    alpha	 alpha level for 1-alpha confidence
+#' @param    rel1  	 estimated reliability in original study
+#' @param    n1   	 sample size in original study
+#' @param    rel2  	 estimated reliability in follow-up study
+#' @param    n2   	 sample size in follow-up study
+#' @param    r   	 number of measurements (e.g., items) 
+#' 
+#' 
+#' @return
+#' A 4-row matrix. The rows are:
+#' * Row 1 summarizes the original study
+#' * Row 2 summarizes the follow-up study
+#' * Row 3 estimates the difference in correlations
+#' * Row 4 estimates the average correlation
+#' 
+#' 
+#' The columns are:
+#' * Estimate - correlation estimate (single study, difference, average)
+#' * SE - standard error
+#' * LL - lower limit of the confidence interval
+#' * UL - upper limit of the confidence interval
+#' 
+#' 
+#' @examples
+#' replicate.cronbach(.05, .883, 100, .869, 200, 6)
+#'
+#' # Should return:
+#' #                       Estimate         SE          LL         UL
+#' # Original:                0.883 0.01830958  0.84356871 0.91522517
+#' # Follow-up:               0.869 0.01442263  0.83874629 0.89523760
+#' # Original - Follow-up:    0.014 0.02330779 -0.03336284 0.05820123
+#' # Average:                 0.876 0.01172239  0.85187755 0.89774525
+#' 
+#' 
+#' @references
+#' * \insertRef{Bonett2010}{vcmeta}
+#' * \insertRef{Bonett2015}{vcmeta}
+#' * \insertRef{Bonett2021}{vcmeta}
+#' 
+#' 
+#' @importFrom stats qnorm
+#' @importFrom stats qf
+#' @export
+replicate.cronbach <- function(alpha, rel1, n1, rel2, n2, r) {
+  zcrit1 <- qnorm(1 - alpha/2)
+  zcrit2 <- qnorm(1 - alpha)
+  se1 <- sqrt((2*r*(1 - rel1)^2)/((r - 1)*(n1 - 2)))
+  df11 <- n1 - 1
+  df12 <- n1*(r - 1)
+  f1 <- qf(1 - alpha/2, df11, df12)
+  f2 <- qf(1 - alpha/2, df12, df11)
+  f0 <- 1/(1 - rel1)
+  ll1 <- 1 - f1/f0
+  ul1 <- 1 - 1/(f0*f2)
+  se2 <- sqrt((2*r*(1 - rel2)^2)/((r - 1)*(n2 - 2)))
+  df21 <- n2 - 1
+  df22 <- n2*(r - 1)
+  f1 <- qf(1 - alpha/2, df21, df22)
+  f2 <- qf(1 - alpha/2, df22, df21)
+  f0 <- 1/(1 - rel2)
+  ll2 <- 1 - f1/f0
+  ul2 <- 1 - 1/(f0*f2)
+  se3 <- sqrt(se1^2 + se2^2)
+  dif <- rel1 - rel2
+  ll3 <- dif - sqrt((rel1 - ll1)^2 + (ul2 - rel2)^2)
+  ul3 <- dif + sqrt((ul1 - rel1)^2 + (rel2 - ll2)^2)
+  hn <- 2/(1/n1 + 1/n2)
+  a <- ((r - 2)*(2 - 1))^.25
+  se10 <- sqrt((2*r*(1 - rel1)^2)/((r - 1)*(n1 - 2 - a)))
+  se20 <- sqrt((2*r*(1 - rel2)^2)/((r - 1)*(n2 - 2 - a)))
+  se4 <- sqrt(se10^2 + se20^2)/2
+  ave <- (rel1 + rel2)/2
+  log.ave <- log(1 - ave) - log(hn/(hn - 1))
+  ul4 <- 1 - exp(log.ave - zcrit1*se4/(1 - ave))
+  ll4 <- 1 - exp(log.ave + zcrit1*se4/(1 - ave))
+  out1 <- t(c(rel1, se1, ll1, ul1))
+  out2 <- t(c(rel2, se2, ll2, ul2))
+  out3 <- t(c(dif, se3, ll3, ul3))
+  out4 <- t(c(ave, se4, ll4, ul4))
+  out <- rbind(out1, out2, out3, out4)
+  colnames(out) <- c("Estimate", "SE", "LL", "UL")
+  rownames(out) <- c("Original:", "Follow-up:", "Original - Follow-up:", "Average:")
+  return(out)
+}
+
